@@ -998,7 +998,7 @@ long DirList::onBeginDrag(FXObject* sender, FXSelector sel, void* ptr)
                 {
                     dragfiles += "\r\n";
                 }
-                dragfiles += ::fileToURI(getItemPathname(item));
+                dragfiles += FXURL::encode(::fileToURI(getItemPathname(item)));
             }
             if (item->first)
             {
