@@ -108,12 +108,14 @@ FXDEFMAP(PreferencesBox) PreferencesMap[] =
     FXMAPFUNC(SEL_COMMAND, PreferencesBox::ID_STANDARD_CONTROLS, PreferencesBox::onCmdControls),
     FXMAPFUNC(SEL_COMMAND, PreferencesBox::ID_CLEARLOOKS_CONTROLS, PreferencesBox::onCmdControls),
     FXMAPFUNC(SEL_COMMAND, PreferencesBox::ID_WHEELADJUST, PreferencesBox::onCmdWheelAdjust),
+    FXMAPFUNC(SEL_COMMAND, PreferencesBox::ID_SCROLLBARSIZE, PreferencesBox::onCmdScrollBarSize),
     FXMAPFUNC(SEL_COMMAND, PreferencesBox::ID_CHANGE_KEYBINDINGS, PreferencesBox::onCmdChangeKeyBindings),
     FXMAPFUNC(SEL_COMMAND, PreferencesBox::ID_RESTORE_KEYBINDINGS, PreferencesBox::onCmdRestoreKeyBindings),
     FXMAPFUNC(SEL_UPDATE, PreferencesBox::ID_STANDARD_CONTROLS, PreferencesBox::onUpdControls),
     FXMAPFUNC(SEL_UPDATE, PreferencesBox::ID_CLEARLOOKS_CONTROLS, PreferencesBox::onUpdControls),
     FXMAPFUNC(SEL_UPDATE, PreferencesBox::ID_COLOR, PreferencesBox::onUpdColor),
     FXMAPFUNC(SEL_UPDATE, PreferencesBox::ID_WHEELADJUST, PreferencesBox::onUpdWheelAdjust),
+    FXMAPFUNC(SEL_UPDATE, PreferencesBox::ID_SCROLLBARSIZE, PreferencesBox::onUpdScrollBarSize),
     FXMAPFUNC(SEL_UPDATE, PreferencesBox::ID_SINGLE_CLICK_FILEOPEN, PreferencesBox::onUpdSingleClickFileopen),
     FXMAPFUNC(SEL_UPDATE, PreferencesBox::ID_CONFIRM_TRASH, PreferencesBox::onUpdTrash),
     FXMAPFUNC(SEL_UPDATE, PreferencesBox::ID_TRASH_BYPASS, PreferencesBox::onUpdTrash),
@@ -210,13 +212,18 @@ PreferencesBox::PreferencesBox(FXWindow* win, FXColor listbackcolor, FXColor lis
     new FXRadioButton(group, _("Start in last visited folder"), this, PreferencesBox::ID_START_LASTDIR);
 
     group = new FXGroupBox(modes, _("Scrolling mode"), GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
-    scroll = new FXCheckButton(group, _("Smooth scrolling in file lists and text windows"));
-    matrix = new FXMatrix(group, 2, MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_Y);
+
+    matrix = new FXMatrix(group, 2, MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP);
+    scroll = new FXCheckButton(matrix, _("Smooth scrolling in file lists and text windows"));
+    FXbool smoothscroll = getApp()->reg().readUnsignedEntry("SETTINGS", "smooth_scroll", true);
+    scroll->setCheck(smoothscroll);
+    new FXLabel(matrix, "", NULL, JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
     new FXLabel(matrix, _("Mouse scrolling speed:"), NULL, JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
     FXSpinner* spinner = new FXSpinner(matrix, 3, this, PreferencesBox::ID_WHEELADJUST, JUSTIFY_RIGHT|LAYOUT_FILL_X|LAYOUT_FILL_ROW, 0, 0, 0, 0, 2, 2, 1, 1);
     spinner->setRange(1, 100);
-    FXbool smoothscroll = getApp()->reg().readUnsignedEntry("SETTINGS", "smooth_scroll", true);
-    scroll->setCheck(smoothscroll);
+    new FXLabel(matrix, _("Scrollbar width:"), NULL, JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
+    spinner = new FXSpinner(matrix, 3, this, PreferencesBox::ID_SCROLLBARSIZE, JUSTIFY_RIGHT|LAYOUT_FILL_X|LAYOUT_FILL_ROW, 0, 0, 0, 0, 2, 2, 1, 1);
+    spinner->setRange(1, 100);
 
     group = new FXGroupBox(modes, _("Root mode"), GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     rootmode = new FXCheckButton(group, _("Allow root mode"));
@@ -546,7 +553,8 @@ PreferencesBox::PreferencesBox(FXWindow* win, FXColor listbackcolor, FXColor lis
     filetooltips_prev = false;
     relativeresize_prev = false;
     show_pathlink_prev = false;
-    value_prev = false;
+    wheellines_prev = 0;
+    scrollbarsize_prev = 0;
     ask_prev = false;
     dnd_prev = false;
     trashmv_prev = false;
@@ -577,7 +585,7 @@ PreferencesBox::PreferencesBox(FXWindow* win, FXColor listbackcolor, FXColor lis
 long PreferencesBox::onUpdColor(FXObject* o, FXSelector s, void* p)
 {
     FXColorWell* cwell = (FXColorWell*)o;
-    int          i = colorsBox->getCurrentItem();
+    int i = colorsBox->getCurrentItem();
 
     cwell->setRGBA(currTheme.color[i]);
 
@@ -588,7 +596,7 @@ long PreferencesBox::onUpdColor(FXObject* o, FXSelector s, void* p)
 long PreferencesBox::onCmdColor(FXObject* o, FXSelector s, void* p)
 {
     FXColorWell* cwell = (FXColorWell*)o;
-    int          i = colorsBox->getCurrentItem();
+    int i = colorsBox->getCurrentItem();
 
     currTheme.color[i] = cwell->getRGBA();
 
@@ -1196,7 +1204,8 @@ long PreferencesBox::onCmdRestoreKeyBindings(FXObject*, FXSelector, void*)
 long PreferencesBox::onCmdAccept(FXObject* o, FXSelector s, void* p)
 {
     FXbool restart_theme = false;
-    FXbool restart_scroll = false;
+    FXbool restart_smoothscroll = false;
+    FXbool restart_scrollbarsize = false;
     FXbool restart_pathlink = false;
     FXbool restart_controls = false;
     FXbool restart_normalfont = false;
@@ -1698,7 +1707,14 @@ long PreferencesBox::onCmdAccept(FXObject* o, FXSelector s, void* p)
     if (scroll->getCheck() != smoothscroll_prev)
     {
         getApp()->reg().write();
-        restart_scroll = true;
+        restart_smoothscroll = true;
+    }
+
+    // Scrollbar size
+    if (getApp()->getScrollBarSize() != scrollbarsize_prev)
+    {
+        getApp()->reg().write();
+        restart_scrollbarsize = true;
     }
 
     // Control themes
@@ -1818,48 +1834,9 @@ long PreferencesBox::onCmdAccept(FXObject* o, FXSelector s, void* p)
     }
 
     // Restart application if necessary
-    if (restart_scroll)
+    if (restart_smoothscroll | restart_scrollbarsize|restart_theme|restart_pathlink|restart_controls|restart_normalfont|restart_textfont)
     {
-        if (BOX_CLICKED_CANCEL != MessageBox::question(this, BOX_OK_CANCEL, _("Restart"), _("Scrolling mode will be changed after restart.\nRestart X File Explorer now?")))
-        {
-            mainWindow->handle(this, FXSEL(SEL_COMMAND, XFileExplorer::ID_RESTART), NULL);
-        }
-    }
-    if (restart_theme)
-    {
-        if (BOX_CLICKED_CANCEL != MessageBox::question(this, BOX_OK_CANCEL, _("Restart"), _("Theme will be changed after restart.\nRestart X File Explorer now?")))
-        {
-            mainWindow->handle(this, FXSEL(SEL_COMMAND, XFileExplorer::ID_RESTART), NULL);
-        }
-    }
-
-    if (restart_pathlink)
-    {
-        if (BOX_CLICKED_CANCEL != MessageBox::question(this, BOX_OK_CANCEL, _("Restart"), _("Path linker will be changed after restart.\nRestart X File Explorer now?")))
-        {
-            mainWindow->handle(this, FXSEL(SEL_COMMAND, XFileExplorer::ID_RESTART), NULL);
-        }
-    }
-
-    if (restart_controls)
-    {
-        if (BOX_CLICKED_CANCEL != MessageBox::question(this, BOX_OK_CANCEL, _("Restart"), _("Button style will be changed after restart.\nRestart X File Explorer now?")))
-        {
-            mainWindow->handle(this, FXSEL(SEL_COMMAND, XFileExplorer::ID_RESTART), NULL);
-        }
-    }
-
-    if (restart_normalfont)
-    {
-        if (BOX_CLICKED_CANCEL != MessageBox::question(this, BOX_OK_CANCEL, _("Restart"), _("Normal font will be changed after restart.\nRestart X File Explorer now?")))
-        {
-            mainWindow->handle(this, FXSEL(SEL_COMMAND, XFileExplorer::ID_RESTART), NULL);
-        }
-    }
-
-    if (restart_textfont)
-    {
-        if (BOX_CLICKED_CANCEL != MessageBox::question(this, BOX_OK_CANCEL, _("Restart"), _("Text font will be changed after restart.\nRestart X File Explorer now?")))
+        if (BOX_CLICKED_CANCEL != MessageBox::question(this, BOX_OK_CANCEL, _("Restart"), _("Preferences will be changed after restart.\nRestart X File Explorer now?")))
         {
             mainWindow->handle(this, FXSEL(SEL_COMMAND, XFileExplorer::ID_RESTART), NULL);
         }
@@ -1890,7 +1867,8 @@ long PreferencesBox::onCmdCancel(FXObject* o, FXSelector s, void* p)
     filetooltips->setCheck(filetooltips_prev);
     relativeresize->setCheck(relativeresize_prev);
     showpathlink->setCheck(show_pathlink_prev);
-    getApp()->setWheelLines(value_prev);
+    getApp()->setWheelLines(wheellines_prev);
+    getApp()->setScrollBarSize(scrollbarsize_prev);
     use_sudo = use_sudo_prev;
     getApp()->reg().writeUnsignedEntry("OPTIONS", "use_sudo", use_sudo);
     scroll->setCheck(smoothscroll_prev);
@@ -1967,7 +1945,8 @@ FXuint PreferencesBox::execute(FXuint placement)
     filetooltips_prev = filetooltips->getCheck();
     relativeresize_prev = relativeresize->getCheck();
     show_pathlink_prev = showpathlink->getCheck();
-    value_prev = getApp()->getWheelLines();
+    wheellines_prev = getApp()->getWheelLines();
+    scrollbarsize_prev = getApp()->getScrollBarSize();
     use_sudo_prev = use_sudo;
     smoothscroll_prev = scroll->getCheck();
     rootmode_prev = rootmode->getCheck();
@@ -2191,6 +2170,28 @@ long PreferencesBox::onUpdWheelAdjust(FXObject* sender, FXSelector, void*)
 }
 
 
+// Set scrollbar size
+long PreferencesBox::onCmdScrollBarSize(FXObject* sender, FXSelector, void*)
+{
+    FXuint value;
+
+    sender->handle(this, FXSEL(SEL_COMMAND, ID_GETINTVALUE), (void*)&value);
+    getApp()->setScrollBarSize(value);
+    getApp()->reg().write();
+    return(1);
+}
+
+
+// Update the scrollbar size button
+long PreferencesBox::onUpdScrollBarSize(FXObject* sender, FXSelector, void*)
+{
+    FXuint value = getApp()->getScrollBarSize();
+
+    sender->handle(this, FXSEL(SEL_COMMAND, ID_SETINTVALUE), (void*)&value);
+    return(1);
+}
+
+
 // Update single click file open button
 long PreferencesBox::onUpdSingleClickFileopen(FXObject* o, FXSelector, void*)
 {
