@@ -134,7 +134,8 @@ private:
     FXbool       relativeresize_prev;
     FXbool       show_pathlink;
     FXbool       show_pathlink_prev;
-    FXuint       value_prev;
+    FXuint       wheellines_prev;
+    FXint        scrollbarsize_prev;
     FXbool       ask_prev;
     FXbool       dnd_prev;
     FXbool       trashmv_prev;
@@ -177,7 +178,7 @@ private:
                        cwell(NULL), use_sudo(false), use_sudo_prev(false), trashcan_prev(false), trashbypass_prev(false),
                        autosave_prev(false), savewinpos_prev(false), diropen_prev(false), fileopen_prev(false),
                        filetooltips_prev(false), relativeresize_prev(false), show_pathlink(false), show_pathlink_prev(false),
-                       value_prev(0), ask_prev(false), dnd_prev(false), trashmv_prev(false), del_prev(false), properties_prev(false),
+                       wheellines_prev(0), scrollbarsize_prev(0), ask_prev(false), dnd_prev(false), trashmv_prev(false), del_prev(false), properties_prev(false),
                        del_emptydir_prev(false), overwrite_prev(false), exec_prev(false),
                        use_clearlooks(false), use_clearlooks_prev(false), rootmode_prev(false),
 #ifdef STARTUP_NOTIFICATION
@@ -220,6 +221,7 @@ public:
         ID_STANDARD_CONTROLS,
         ID_CLEARLOOKS_CONTROLS,
         ID_WHEELADJUST,
+        ID_SCROLLBARSIZE,
         ID_SINGLE_CLICK_FILEOPEN,
         ID_FILE_TOOLTIPS,
         ID_RELATIVE_RESIZE,
@@ -248,6 +250,8 @@ public:
     long   onUpdSuMode(FXObject*, FXSelector, void*);
     long   onCmdWheelAdjust(FXObject*, FXSelector, void*);
     long   onUpdWheelAdjust(FXObject*, FXSelector, void*);
+    long   onCmdScrollBarSize(FXObject*, FXSelector, void*);
+    long   onUpdScrollBarSize(FXObject*, FXSelector, void*);
     long   onUpdSingleClickFileopen(FXObject*, FXSelector, void*);
     FXuint execute(FXuint);
     long   onCmdCancel(FXObject*, FXSelector, void*);
