@@ -668,9 +668,8 @@ PropertiesBox::PropertiesBox(FXWindow* win, FXString file, FXString path) : Dial
         new FXLabel(mtmatrix, _("File system:"), NULL, LAYOUT_LEFT);
         mtType = new FXLabel(mtmatrix, FXString::null, NULL, LAYOUT_LEFT|LAYOUT_FILL_COLUMN|JUSTIFY_LEFT);
         new FXLabel(mtmatrix, _("Location:"), NULL, LAYOUT_LEFT);
-
-        //location=new FXText(mtmatrix,NULL,LAYOUT_FILL_X|LAYOUT_FILL_Y); // Use an FXText to allow long text strings
-        location = new FXLabel(mtmatrix, FXString::null, NULL, LAYOUT_LEFT|LAYOUT_FILL_COLUMN|JUSTIFY_LEFT);
+        location = new TextLabel(mtmatrix, 30, 0, 0, LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FILL_ROW|FRAME_NONE);
+    	location->setBackColor(getApp()->getBaseColor());
     }
     else
     {
@@ -683,7 +682,8 @@ PropertiesBox::PropertiesBox(FXWindow* win, FXString file, FXString path) : Dial
         new FXLabel(attrmatrix, FXString::null, NULL, LAYOUT_LEFT|JUSTIFY_LEFT);
         fileSizeDetails = new FXLabel(attrmatrix, FXString::null, NULL, LAYOUT_LEFT|JUSTIFY_LEFT);
         new FXLabel(attrmatrix, _("Location:"), NULL, LAYOUT_LEFT);
-        location = new FXLabel(attrmatrix, FXString::null, NULL, LAYOUT_LEFT|LAYOUT_FILL_COLUMN|JUSTIFY_LEFT);
+        location = new TextLabel(attrmatrix, 30, 0, 0, LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FILL_ROW|FRAME_NONE);
+    	location->setBackColor(getApp()->getBaseColor());
 
         if (isLink & !isBrokenLink)
         {
@@ -765,6 +765,8 @@ PropertiesBox::PropertiesBox(FXWindow* win, FXString file, FXString path) : Dial
         }
     }
 
+	// Set location text
+	location->setNumColumns(text.length());
     location->setText(text);
 
     // Referred file for valid or broken link
