@@ -1,6 +1,7 @@
 #ifndef PROPERTIES_H
 #define PROPERTIES_H
 
+#include "TextLabel.h"
 #include "DialogBox.h"
 
 class PropertiesBox;
@@ -59,7 +60,7 @@ private:
 	int          nbseldirs;
     FXLabel*     fileSize;
     FXLabel*     fileSizeDetails;
-    FXLabel*     location;
+    TextLabel*   location;
     FXLabel*     origlocation;
     FXLabel*     linkto;
     FXLabel*     deletiondate;
