@@ -277,7 +277,7 @@ public:
         dirpanel->setDefaultCursor(cur);
     }
 
-	// Deslect all items
+	// Deselect all items
     void deselectAll(void)
     {
         lpanel->deselectAll();
@@ -289,11 +289,11 @@ public:
 		}
     }
 	 
-    // Redraw file lists
-    void redrawPanels(void)
+    // Refresh file panels
+    void refreshPanels(void)
     {
-        lpanel->redraw();
-        rpanel->redraw();
+        lpanel->onCmdRefresh(0, 0, 0);
+        rpanel->onCmdRefresh(0, 0, 0);
     }
 
     // Return a pointer on the current file panel
