@@ -1,17 +1,17 @@
 // Common Xfe constants
 
 #ifndef COPYRIGHT
-#define COPYRIGHT    "Copyright (C) 2002-2017 Roland Baudin (roland65@free.fr)"
+#define COPYRIGHT    "Copyright (C) 2002-2018 Roland Baudin (roland65@free.fr)"
 #endif
 
 // Default normal font
 #ifndef DEFAULT_NORMAL_FONT
-#define DEFAULT_NORMAL_FONT    "Helvetica,100,normal,regular"
+#define DEFAULT_NORMAL_FONT    "Sans,100,normal,regular"
 #endif
 
 // Default text font
 #ifndef DEFAULT_TEXT_FONT
-#define DEFAULT_TEXT_FONT    "Courier,100,normal,regular"
+#define DEFAULT_TEXT_FONT    "Mono,100,normal,regular"
 #endif
 
 // Default file and directory list time format
